@@ -50,7 +50,7 @@ async def _init_db(model: Type[TModel], collection_name):
 class Model(pydantic.BaseModel, ABC):
     # https://pymongo.readthedocs.io/en/4.1.1/api/pymongo/operations.html#pymongo.operations.IndexModel
     indexes: Sequence[IndexModel]
-    id: Optional[str]
+    id: Optional[str] = None
 
     class Config:
         # IndexModel validation is missing for pydantic so it requires this
@@ -80,8 +80,10 @@ class Model(pydantic.BaseModel, ABC):
             raise ModelNotFoundError()
 
         del doc["_id"]
-        for key in doc:
-            setattr(self, key, doc[key])
+        item = self.__class__(id=self.id, **doc)
+        for key in item.get_data():
+            setattr(self, key, getattr(item, key))
+
         await self.after_load()
 
     async def after_load(self) -> None:
